==> jc-1.4.0.tar.gz: java/lang/VerifyError.h <==
// public class java.lang.VerifyError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 88eb5740b1264f9 java_lang_VerifyError

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_VerifyError_H_
#define _JC_java_lang_VerifyError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VerifyError$sub_refs	_jc_java_lang_VerifyError$sub_refs;
typedef struct _jc_java_lang_VerifyError$sub_nonrefs	_jc_java_lang_VerifyError$sub_nonrefs;
typedef struct _jc_java_lang_VerifyError$refs	_jc_java_lang_VerifyError$refs;
typedef struct _jc_java_lang_VerifyError$nonrefs	_jc_java_lang_VerifyError$nonrefs;
typedef struct _jc_java_lang_VerifyError$object	_jc_java_lang_VerifyError$object;

typedef struct _jc_java_lang_VerifyError$fields_struct	_jc_java_lang_VerifyError$fields_struct;
typedef const struct _jc_java_lang_VerifyError$vmethods	_jc_java_lang_VerifyError$vmethods;
typedef const struct _jc_java_lang_VerifyError$vtable	_jc_java_lang_VerifyError$vtable;
typedef const struct _jc_java_lang_VerifyError$vtype	_jc_java_lang_VerifyError$vtype;

// Class fields structure
struct _jc_java_lang_VerifyError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_VerifyError$fields_struct _jc_java_lang_VerifyError$class_fields;

// Constructors
extern void _jc_java_lang_VerifyError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VerifyError$object *);
extern void _jc_java_lang_VerifyError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_VerifyError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_VerifyError$vmethods {
};

// Vtable
struct _jc_java_lang_VerifyError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_VerifyError$vmethods	java_lang_VerifyError;
};

// Vtype
struct _jc_java_lang_VerifyError$vtype {
	_jc_type			type;
	_jc_java_lang_VerifyError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VerifyError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VerifyError$refs {
    _jc_java_lang_VerifyError$sub_refs	java_lang_VerifyError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VerifyError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VerifyError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_VerifyError$sub_nonrefs	java_lang_VerifyError;
};

// Object instance structure
struct _jc_java_lang_VerifyError$object {
	_jc_java_lang_VerifyError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VerifyError$vtype	*vtype;
	_jc_java_lang_VerifyError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VerifyError$vtype _jc_java_lang_VerifyError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VerifyError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VerifyError$class_object;

#endif	/* _JC_java_lang_VerifyError_H_ */

==> jc-1.4.6.tar.gz: java/lang/VerifyError.h <==
// public class java.lang.VerifyError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 88eb5740b1264f9 java_lang_VerifyError

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_VerifyError_H_
#define _JC_java_lang_VerifyError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VerifyError$sub_refs	_jc_java_lang_VerifyError$sub_refs;
typedef struct _jc_java_lang_VerifyError$sub_nonrefs	_jc_java_lang_VerifyError$sub_nonrefs;
typedef struct _jc_java_lang_VerifyError$refs	_jc_java_lang_VerifyError$refs;
typedef struct _jc_java_lang_VerifyError$nonrefs	_jc_java_lang_VerifyError$nonrefs;
typedef struct _jc_java_lang_VerifyError$object	_jc_java_lang_VerifyError$object;

typedef struct _jc_java_lang_VerifyError$fields_struct	_jc_java_lang_VerifyError$fields_struct;
typedef const struct _jc_java_lang_VerifyError$vmethods	_jc_java_lang_VerifyError$vmethods;
typedef const struct _jc_java_lang_VerifyError$vtable	_jc_java_lang_VerifyError$vtable;
typedef const struct _jc_java_lang_VerifyError$vtype	_jc_java_lang_VerifyError$vtype;

// Class fields structure
struct _jc_java_lang_VerifyError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_VerifyError$fields_struct _jc_java_lang_VerifyError$class_fields;

// Constructors
extern void _jc_java_lang_VerifyError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VerifyError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VerifyError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_VerifyError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VerifyError$vmethods {
};

// Vtable
struct _jc_java_lang_VerifyError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_VerifyError$vmethods	java_lang_VerifyError;
};

// Vtype
struct _jc_java_lang_VerifyError$vtype {
	_jc_type			type;
	_jc_java_lang_VerifyError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VerifyError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VerifyError$refs {
    _jc_java_lang_VerifyError$sub_refs	java_lang_VerifyError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VerifyError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VerifyError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_VerifyError$sub_nonrefs	java_lang_VerifyError;
};

// Object instance structure
struct _jc_java_lang_VerifyError$object {
	_jc_java_lang_VerifyError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VerifyError$vtype	*vtype;
	_jc_java_lang_VerifyError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VerifyError$vtype _jc_java_lang_VerifyError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VerifyError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VerifyError$class_object;

#endif	/* _JC_java_lang_VerifyError_H_ */
